@@ -107,7 +107,7 @@ from .extfields import (
 
 from .subclass import SubClass
 
-from .errors import standard_readable_error_for_typedpy_exception, ErrorInfo
+from .errors import standard_readable_error_for_typedpy_exception, ErrorInfo, get_simplified_error
 
 from .utility import get_list_type, type_is_generic
 
@@ -115,6 +115,13 @@ from .mappers import mappers, Deleted, Constant, DoNotSerialize
 
 from .versioned_mapping import convert_dict, Versioned
 
-from .commons import nested, deep_get, first_in, flatten, default_factories
+from .commons import (
+    nested,
+    deep_get,
+    first_in,
+    flatten,
+    default_factories,
+    InvalidStructureErr
+)
 
 from .keysof import keys_of
